@@ -196,8 +196,8 @@ main(int argc, char *argv[])
   char tempfilename[BUFSIZ], bFilename[BUFSIZ], dFilename[BUFSIZ],
        eFilename[BUFSIZ], cFilename[BUFSIZ], kFilename[BUFSIZ],
        uFilename[BUFSIZ], poolfilename[BUFSIZ], line[BUFSIZ];
-  char send_to[] = "";
-  char message_from[] = "";
+  char *send_to = alloca(BUFSIZ);
+  char *message_from = alloca(BUFSIZ);
   int recursing, trimmings = 0;
   int tempfd;
   enum message_type anon;
@@ -216,7 +216,7 @@ main(int argc, char *argv[])
       exit(0);
     }
     else {
-      printf("Freedom Remailer 2.1.1 "
+      printf("Freedom Remailer 2.1.2 "
 	     "(C) John B. Fleming 1995, Johannes Kroeger 1997\n\n"
 	     "Usage: %s\t\t# read mail on stdin and process\n"
 	     "       %s -q\t# run queue of latent messages\n",
